@@ -698,6 +698,9 @@ thunar_apr_desktop_page_file_changed (ThunarAprAbstractPage *abstract_page,
       gtk_editable_set_editable (GTK_EDITABLE (desktop_page->comment_entry), writable);
       gtk_widget_set_sensitive (desktop_page->snotify_button, writable);
       gtk_widget_set_sensitive (desktop_page->terminal_button, writable);
+      gtk_widget_set_sensitive (desktop_page->program_button, writable);
+      if (desktop_page->trusted_button != NULL)
+        gtk_widget_set_sensitive (desktop_page->trusted_button, writable);
 
       /* cleanup */
       g_free (type);
@@ -1056,7 +1059,7 @@ thunar_apr_desktop_page_program_toggled (GtkWidget            *button,
   if (error != NULL)
     {
       g_warning ("Error while setting execution flag : %s", error->message);
-      g_free (error);
+      g_error_free (error);
       return;
     }
 
@@ -1091,7 +1094,7 @@ thunar_apr_desktop_page_trusted_toggled (GtkWidget            *button,
   if (error != NULL)
     {
       g_warning ("Error while setting safety flag : %s", error->message);
-      g_free (error);
+      g_error_free (error);
       return;
     }
 
