@@ -29,6 +29,14 @@
 #include <gio/gdesktopappinfo.h>
 #endif
 
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h> /* realpath */
+#endif
+
+#ifndef HAVE_REALPATH
+#define realpath(path, resolved_path) NULL
+#endif
+
 #include <libxfce4util/libxfce4util.h>
 
 #include <thunar/thunar-file.h>
@@ -185,7 +193,7 @@ thunar_g_file_new_for_symlink_target (GFile *file)
       return NULL;
     }
 
-  target_path = g_file_info_get_symlink_target (info);
+  target_path = g_file_info_get_attribute_byte_string (info, G_FILE_ATTRIBUTE_STANDARD_SYMLINK_TARGET);
   file_parent = g_file_get_parent (file);
 
   /* if target_path is an absolute path, the target_gfile is created using only the target_path
@@ -449,7 +457,7 @@ thunar_g_file_guess_device_type (GFile *file)
   if (fileinfo == NULL)
     return NULL;
 
-  icon = g_file_info_get_icon (fileinfo);
+  icon = G_ICON (g_file_info_get_attribute_object (fileinfo, G_FILE_ATTRIBUTE_STANDARD_ICON));
   if (!G_IS_THEMED_ICON (icon))
     {
       g_object_unref (fileinfo);
@@ -1372,4 +1380,87 @@ thunar_g_file_is_desktop_file (GFile *file)
   
   g_free (basename);
   return is_desktop_file;
+}
+
+
+
+/**
+ * thunar_g_file_get_link_path_for_symlink:
+ * @file_to_link : the #GFile to which @symlink will have to point
+ * @symlink      : a #GFile representing the symlink
+ *
+ * Method to build the link target path in order to link from @symlink to @file_to_link.
+ * The caller is responsible for freeing the string using g_free() when done.
+ *
+ * Return value: The link path, or NULL on failure
+ **/
+char *
+thunar_g_file_get_link_path_for_symlink (GFile *file_to_link,
+                                         GFile *symlink)
+{
+    GFile *root;
+    GFile *parent;
+    char  *relative_path;
+    char  *link_path;
+
+  _thunar_return_val_if_fail (G_IS_FILE (file_to_link), NULL);
+  _thunar_return_val_if_fail (G_IS_FILE (symlink), NULL);
+
+    /* */
+    if (g_file_is_native (file_to_link) || g_file_is_native (symlink))
+    {
+        return g_file_get_path (file_to_link);
+    }
+
+    /* Search for the filesystem root */
+    root = g_object_ref (file_to_link);
+    while ((parent = g_file_get_parent (root)) != NULL)
+    {
+        g_object_unref (root);
+        root = parent;
+    }
+
+    /* Build a absolute path, using the relative path up to the filesystem root */
+    relative_path = g_file_get_relative_path (root, file_to_link);
+    g_object_unref (root);
+    link_path = g_strconcat ("/", relative_path, NULL);
+    g_free (relative_path);
+    return link_path;
+}
+
+
+
+/**
+ * thunar_g_file_get_resolved_path:
+ * @file : #GFile for which the path will be resolved
+ *
+ * Gets the local pathname with resolved symlinks for GFile, if one exists.
+ * If non-NULL, this is guaranteed to be an absolute, canonical path.
+ *
+ * This only will work if all components of the #GFile path actually do exist
+ *
+ * Return value: (nullable) (transfer full): A #gchar on success and %NULL on failure.
+ * The returned string should be freed with g_free() when no longer needed.
+ **/
+char*
+thunar_g_file_get_resolved_path (GFile *file)
+{
+  gchar *path;
+  gchar *real_path;
+
+  _thunar_return_val_if_fail (G_IS_FILE (file), NULL);
+
+  path = g_file_get_path (file);
+
+  /* No local path for file found */
+  if (path == NULL)
+    return NULL;
+
+  real_path = realpath (path, NULL);
+
+  if (real_path == NULL)
+    g_warning ("Failed to resolve path: '%s' Error: %s\n", path, strerror (errno));
+
+  g_free (path);
+  return real_path;
 }
\ No newline at end of file
