@@ -23,18 +23,23 @@
 
 #include <glib.h>
 #include <thunar/thunar-device.h>
+#include <thunar/thunar-job-operation.h>
 
 G_BEGIN_DECLS
 
-void thunar_notify_unmount        (ThunarDevice *device);
+void     thunar_notify_unmount     (ThunarDevice *device);
 
-void thunar_notify_eject          (ThunarDevice *device);
+void     thunar_notify_eject       (ThunarDevice *device);
 
-void thunar_notify_progress       (ThunarDevice *device, const gchar *message_to_show);
+void     thunar_notify_progress    (ThunarDevice *device, const gchar *message_to_show);
 
-void thunar_notify_finish         (ThunarDevice *device);
+void     thunar_notify_finish      (ThunarDevice *device);
 
-void thunar_notify_uninit         (void);
+void     thunar_notify_undo        (ThunarJobOperation *operation);
+
+void     thunar_notify_redo        (ThunarJobOperation *operation);
+
+void     thunar_notify_uninit      (void);
 
 G_END_DECLS
 
