@@ -97,6 +97,7 @@ thunar_progress_dialog_init (ThunarProgressDialog *dialog)
   gtk_window_set_default_size (GTK_WINDOW (dialog), 450, 10);
   gtk_window_set_modal (GTK_WINDOW (dialog), FALSE);
   gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), FALSE);
+  gtk_window_set_type_hint (GTK_WINDOW (dialog), GDK_WINDOW_TYPE_HINT_DIALOG);
 
   g_signal_connect (dialog, "delete-event",
                     G_CALLBACK (thunar_progress_dialog_closed), dialog);
@@ -234,7 +235,7 @@ launch_waiting_jobs (ThunarProgressDialog *dialog)
           dialog->views         = g_list_concat (lp, dialog->views);
           thunar_progress_view_launch_job (THUNAR_PROGRESS_VIEW (lp->data));
 
-          job_list = g_list_prepend (job_list, lp->data);
+          job_list = g_list_prepend (job_list, thunar_progress_view_get_job (THUNAR_PROGRESS_VIEW (lp->data)));
         }
       lp = next;
     }
